#!/bin/sh
#
# Generation & rendering of a random flame 
#
set -e
set x
#
flam3-genome > random.flam3
xmllint -noout random.flam3
flam3-render < random.flam3
pngcheck 00000.png
